# merqube-client-lib
MerQube API Client Library (Python)
[![CircleCI](https://dl.circleci.com/status-badge/img/gh/merqube/merqube-client-lib/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/merqube/merqube-client-lib/tree/main)

## Overview

This is a python client library for MerQube's public API.
This is a WIP release of an internal client library. This README will be updated when it is ready. More functionality will be added here over the coming weeks.

Table Of Contents:
- [Overview](docs/Overview.md)
- [Data Retrieval](docs/DataRetrieval.md)
- [Creating Indices](docs/CreatingIndices.md)
- [History of Changes](Changelog.md)
